from daily_tasks.commands.main_commands import *
from daily_tasks.commands.modification_commands import *
from daily_tasks.commands.filter_commands import *
from daily_tasks.commands.removal_commands import *
from daily_tasks.commands.utilities import *



import click as ck
from daily_tasks.commands.main_commands import add, view
from daily_tasks.commands.modification_commands import modify
from daily_tasks.commands.removal_commands import delete
from daily_tasks.commands.filter_commands import filter_tasks


@ck.group
def daily_tasks() -> None:
    """A tasks manager for those who like work from shell."""


daily_tasks.add_command(add)
daily_tasks.add_command(view)
daily_tasks.add_command(modify)
daily_tasks.add_command(delete)
daily_tasks.add_command(filter_tasks, name='filter')



import json
import click as ck
from daily_tasks.commands import utilities


@ck.command
@ck.option(
    '-id', '--task-id',
    type=ck.INT,
    required=False
)
@ck.option(
    '--done',
    is_flag=True,
    required=False
)
def delete(task_id, done):
    """Delete tasks."""
    with open(utilities.tasks_file_path, 'r', encoding='utf-8') as reading_tasks_file:
        tasks = json.load(reading_tasks_file)

    if task_id:
        for task in tasks:
            if task['id'] == task_id:
                task_index = tasks.index(task)
                tasks.pop(task_index)

    for task in tasks:
        if done:
            done_status = utilities.STATUS[2]

            if task['status'] == done_status:
                task_index = tasks.index(task)
                tasks.pop(task_index)

    with open(utilities.tasks_file_path, 'w', encoding='utf-8') as writing_tasks_file:
        json.dump(tasks, writing_tasks_file, indent=2)



from datetime import datetime # pylint: disable=unused-import
import json
import click as ck
from daily_tasks.commands import utilities


@ck.command
@ck.option(
    '-p', '--priority',
    type=ck.Choice(utilities.PRIORITIES, case_sensitive=False),
    required=False
)
@ck.option(
    '-s', '--status',
    type=ck.Choice(utilities.STATUS, case_sensitive=False),
    required=False
)
@ck.option(
    '-dd', '--due-date',
    type=ck.DateTime(formats=utilities.DUE_DATE_FORMAT),
    required=False
)
def filter_tasks(priority, status, due_date):
    "Filter tasks, use only one option for better results."
    with open(utilities.tasks_file_path, 'r', encoding='utf-8') as reading_tasks_file:
        tasks = json.load(reading_tasks_file)

    if priority:

        priority_upper = priority.upper()

        for task in tasks:
            if task['priority'] == priority_upper:

                task_id = task['id']
                task_description = task['description']
                task_priority = task['priority']
                task_due_date = task['due_date']
                task_status = task['status']

                utilities.stylized_tasks_printing(task_id, task_description, task_priority, task_due_date, task_status)

    if status:

        status_capitalize = status.capitalize()

        for task in tasks:
            if task['status'] == status_capitalize:

                task_id = task['id']
                task_description = task['description']
                task_priority = task['priority']
                task_due_date = task['due_date']
                task_status = task['status']

                utilities.stylized_tasks_printing(task_id, task_description, task_priority, task_due_date, task_status)

    if due_date:
        
        due_date_date_object = due_date.date()
        due_date_formatted = due_date_date_object.strftime(utilities.DUE_DATE_FORMAT[0])

        for task in tasks:
            if task['due_date'] == due_date_formatted:

                task_id = task['id']
                task_description = task['description']
                task_priority = task['priority']
                task_due_date = task['due_date']
                task_status = task['status']

                utilities.stylized_tasks_printing(task_id, task_description, task_priority, task_due_date, task_status)



"""Main commands of this CLI"""
import json

import click as ck
from daily_tasks.commands import utilities


@ck.command
@ck.option('-d', '--description',
           required=True,
           type=ck.STRING,
           help="Describe your task."
           )
@ck.option('-p', '--priority',
           type=ck.Choice(utilities.PRIORITIES, case_sensitive=False),
           help="Choose a priority to your task.",
           default=utilities.PRIORITIES[3]
           )
@ck.option('-dd', '--due-date',
           type=ck.DateTime(formats=utilities.DUE_DATE_FORMAT),
           help="Set a due date to your task.",
           default=utilities.get_due_date_default_value()
           )
@ck.option('-s', '--status',
           type=ck.Choice(utilities.STATUS, case_sensitive=False),
           help="Choose a status to your task.",
           default=utilities.STATUS[3]
           )
@ck.option('-f', '--file-path',
           hidden=True,
           required=False,
           type=ck.STRING,
           default=utilities.tasks_file_path,
           help="This option is ONLY FOR TESTING."
           )
def add(description, priority, due_date, status, file_path=utilities.tasks_file_path) -> None: # pylint: disable=unused-argument
    """Create a new task."""
    
    with open(utilities.tasks_file_path, 'r', encoding='utf-8') as tasks_file_read:
        tasks = json.load(tasks_file_read)

    if tasks == []:
        new_id = 1
    else:
        last_task = tasks[-1]
        last_id = last_task['id']
        new_id = last_id + 1

    priority_upper = priority.upper()
    status_capitalize = status.capitalize()

    due_date_date_obj = due_date.date()
    due_date_formatted = due_date_date_obj.strftime(utilities.DUE_DATE_FORMAT[0])

    tasks.append(
        {
            "id": new_id,
            "description": f"{description}",
            "priority": f"{priority_upper}",
            "due_date": f"{due_date_formatted}",
            "status": f"{status_capitalize}"
        }
    )

    with open(utilities.tasks_file_path, 'w', encoding='utf-8') as tasks_file_write:
        json.dump(tasks, tasks_file_write, indent=2)


@ck.command
@ck.option('-f', '--file-path',
           hidden=True,
           required=False,
           type=ck.STRING,
           default=utilities.tasks_file_path,
           help="This option is ONLY FOR TESTING."
           )
def view(file_path=utilities.tasks_file_path) -> None: # pylint: disable=unused-argument
    """View all your tasks."""
    with open(utilities.tasks_file_path, 'r', encoding='utf-8') as tasks_file:
        tasks = json.load(tasks_file)

    for task in tasks:

        task_id = task['id']
        description = task['description']
        priority = task['priority']
        due_date = task['due_date']
        status = task['status']

        utilities.stylized_tasks_printing(task_id, description, priority, due_date, status)



from setuptools import setup, find_packages

install_requires = [
    "click>=8.1.7",
    "colorama>=0.4.6"
]

extras_require = {
    'dev': ['pylint>=3.1.0', 'click>=8.1.7', 'twine>=5.0.0'],
}

with open('README.md', 'r', encoding='utf-8') as readme_file:
    long_description = readme_file.read()

setup(
    name="dailytasks",
    version="2.0.0",
    description="A tasks manager for those who like work from shell.",
    long_description=long_description,
    long_description_content_type='text/markdown',
    author="LuisanaMTDev",
    author_email="luisanamartineztorres25@gmail.com",
    url='https://github.com/LuisanaMTDev/dailytasks',
    license="Apache-2.0",
    classifiers=[
        'Environment :: Console',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Apache Software License',
        'Programming Language :: Python :: 3.11',
        'Topic :: Utilities'
    ],
    install_requires=install_requires,
    extras_require=extras_require,
    packages=find_packages(),
    include_package_data=True,
    package_data={'data_files': ['*.json']},
    python_requires=">=3.11",
    entry_points={
        'console_scripts': [
            'dailytasks = daily_tasks.commands.main:daily_tasks',
        ],
    },
)



from datetime import datetime # pylint: disable=unused-import
import json
import click as ck
from daily_tasks.commands import utilities


@ck.command
@ck.option(
    '-id', '--task-id',
    type=ck.INT,
    required=True
)
@ck.option(
    '-d', '--new-description',
    type=ck.STRING,
    required=False
)
@ck.option(
    '-p', '--new-priority',
    type=ck.Choice(utilities.PRIORITIES, case_sensitive=False),
    required=False
)
@ck.option(
    '-s', '--new-status',
    type=ck.Choice(utilities.STATUS, case_sensitive=False),
    required=False
)
@ck.option(
    '-dd', '--new-due-date',
    type=ck.DateTime(formats=utilities.DUE_DATE_FORMAT),
    required=False
)
def modify(task_id, new_description, new_priority, new_status, new_due_date):
    "Modify a task info."
    with open(utilities.tasks_file_path, 'r', encoding='utf-8') as tasks_file_read:
        tasks = json.load(tasks_file_read)

    for task in tasks:
        if task['id'] == task_id:
            extracted_task = task
            break

    task_index = tasks.index(extracted_task)

    if new_description:
        extracted_task['description'] = new_description.capitalize()

    if new_priority:
        new_priority_upper = new_priority.upper()
        extracted_task['priority'] = new_priority_upper

    if new_status:
        new_status_capitalize = new_status.capitalize()
        extracted_task['status'] = new_status_capitalize

    if new_due_date:
        new_due_date_date_object = new_due_date.date()
        new_due_date_formatted = new_due_date_date_object.strftime(utilities.DUE_DATE_FORMAT[0])

        extracted_task['due_date'] = new_due_date_formatted

    tasks.pop(task_index)
    tasks.insert(task_index, extracted_task)

    with open(utilities.tasks_file_path, 'w', encoding='utf-8') as tasks_file_write:
        json.dump(tasks, tasks_file_write, indent=2)
